/**
 * Simple React components that interact with the OpenID-Connect state.
 *
 * Use them as-is if they fit your needs, or read their code for
 * inspiration.
 */
import { ReactNode, FC } from "react";
import { State, StateEnum } from "./OpenIDConnect";
/**
 * An “if” block that only renders children when the OpenID-Connect
 * state machine is currently in a given condition.
 */
export declare function IfOIDCState(props: {
    children?: ReactNode;
    is?: StateEnum;
    isnt?: StateEnum;
    isOneOf?: StateEnum[];
    isNoneOf?: StateEnum[];
}): ReturnType<FC>;
/**
 * A simple &lt;span&gt; that shows the OIDC error if any.
 *
 * Renders to nothing (&lt;&gt;&lt;/&gt;) if there is no error (so you don't even have to
 * wrap it in an &lt;IfOIDCState&gt;).
 */
export declare function OIDCError(props: {
    className: string;
}): JSX.Element;
export declare function LoggedInUser(props: {
    field: string;
}): JSX.Element;
export interface LoginButtonTexts {
    label: ReactNode;
    tooltip: string;
}
export interface LoginButtonProps {
    inProgressLabel?: ReactNode | ((oidc: State) => ReactNode);
    loginLabel?: ReactNode | ((oidc: State) => ReactNode);
    logoutLabel?: ReactNode | ((oidc: State) => ReactNode);
    loginTooltip?: string | ((oidc: State) => string);
    logoutTooltip?: string | ((oidc: State) => string);
    className?: string | ((oidc: State) => string);
    showError?: ((oidc: State, texts: LoginButtonTexts) => LoginButtonTexts);
}
/**
 * A standard-issue login / logout button.
 */
export declare function LoginButton(props: LoginButtonProps): JSX.Element;
