"use strict";

require("core-js/modules/web.dom-collections.iterator.js");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.IfOIDCState = IfOIDCState;
exports.LoggedInUser = LoggedInUser;
exports.LoginButton = LoginButton;
exports.OIDCError = OIDCError;
require("core-js/modules/es.symbol.description.js");
var React = _interopRequireWildcard(require("react"));
var _OpenIDConnect = require("./OpenIDConnect");
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return typeof key === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (typeof input !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (typeof res !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); } /**
                                                                                                                                                                                                                                                                                                                                                                                           * Simple React components that interact with the OpenID-Connect state.
                                                                                                                                                                                                                                                                                                                                                                                           *
                                                                                                                                                                                                                                                                                                                                                                                           * Use them as-is if they fit your needs, or read their code for
                                                                                                                                                                                                                                                                                                                                                                                           * inspiration.
                                                                                                                                                                                                                                                                                                                                                                                           */
/////////////////////////////////  IfOIDCState /////////////////////////////////////////////

/**
 * An “if” block that only renders children when the OpenID-Connect
 * state machine is currently in a given condition.
 */
function IfOIDCState(props) {
  const {
    state
  } = (0, _OpenIDConnect.useOpenIDConnectContext)();
  if (props.is) {
    return childrenIf(props.is === state);
  } else if (props.isnt) {
    return childrenIf(props.is !== state);
  } else if (props.isOneOf) {
    return childrenIf(props.isOneOf.some(s => s === state));
  } else if (props.isNoneOf) {
    return childrenIf(!props.isNoneOf.some(s => s === state));
  }
  function childrenIf(predicate) {
    return predicate ? /*#__PURE__*/React.createElement(React.Fragment, null, props.children) : /*#__PURE__*/React.createElement(React.Fragment, null);
  }
}

//////////////////////////////////  OIDCError //////////////////////////////////////////////

/**
 * A simple &lt;span&gt; that shows the OIDC error if any.
 *
 * Renders to nothing (&lt;&gt;&lt;/&gt;) if there is no error (so you don't even have to
 * wrap it in an &lt;IfOIDCState&gt;).
 */
function OIDCError(props) {
  const {
    className
  } = props;
  const {
    error
  } = (0, _OpenIDConnect.useOpenIDConnectContext)();
  if (!error) return /*#__PURE__*/React.createElement(React.Fragment, null);
  return /*#__PURE__*/React.createElement("span", {
    className: className
  }, "error");
}

///////////////////////////////  LoggedInUser //////////////////////////////////////////////

function LoggedInUser(props) {
  const {
    idToken
  } = (0, _OpenIDConnect.useOpenIDConnectContext)();
  return /*#__PURE__*/React.createElement(React.Fragment, null, idToken[props.field]);
}

/////////////////////////////////  LoginButton /////////////////////////////////////////////

const LoginButtonDefaults = {
  loginLabel: "Login",
  logoutLabel: "Logout",
  inProgressLabel: "⌛",
  loginTooltip: "Log in with OpenID-Connect",
  logoutTooltip: "Log out",
  showError: (oidc, _ref) => {
    let {
      label,
      tooltip
    } = _ref;
    if (oidc.error === undefined) {
      return {
        label,
        tooltip
      };
    } else {
      return {
        label: /*#__PURE__*/React.createElement(React.Fragment, null, "React.Children.toArray(label).concat([", /*#__PURE__*/React.createElement("sup", null, "\u26A0"), "])"),
        tooltip: "".concat(oidc.error)
      };
    }
  }
};

/**
 * A standard-issue login / logout button.
 */
function LoginButton(props) {
  props = _objectSpread(_objectSpread({}, LoginButtonDefaults), props);
  const oidc = (0, _OpenIDConnect.useOpenIDConnectContext)();
  const className = getString(props.className);
  if (oidc.state === _OpenIDConnect.StateEnum.InProgress) {
    const pleaseWait = getElements(props.inProgressLabel);
    return /*#__PURE__*/React.createElement("button", {
      className: className,
      disabled: true
    }, pleaseWait);
  }
  const loggedIn = oidc.state === _OpenIDConnect.StateEnum.LoggedIn;
  let label = getElements(loggedIn ? props.logoutLabel : props.loginLabel),
    tooltip = getString(loggedIn ? props.logoutTooltip : props.loginTooltip);
  if (props.showError) {
    const errorAppearance = props.showError(oidc, {
      label,
      tooltip
    });
    label = errorAppearance.label;
    tooltip = errorAppearance.tooltip;
  }
  function click() {
    if (loggedIn) {
      oidc.logout();
    } else {
      oidc.login();
    }
  }
  return /*#__PURE__*/React.createElement("button", {
    className: className,
    title: tooltip,
    onClick: click
  }, label);
  function getString(stringGiver) {
    return typeof stringGiver === 'function' ? stringGiver(oidc) : stringGiver;
  }
  function getElements(elementGiver) {
    return typeof elementGiver === 'function' ? elementGiver(oidc) : elementGiver;
  }
}
//# sourceMappingURL=sundry-widgets.js.map