"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useInterval = useInterval;
exports.useTimeout = useTimeout;
var _react = require("react");
/**
 * More `useFoo` hooks not found in either React or https://usehooks-ts.com/
 */

/**
 * Like https://usehooks-ts.com/react-hook/use-interval but with OO API.
 *
 * The API allows the caller to start, stop, restart, or change the
 * callback or frequency at any time. The interval is automatically
 * destroyed when the owner component unmounts, regardless of its
 * state at that time.
 */
function useInterval() {
  return useJavascriptTimer(setInterval, clearInterval);
}

/**
 * Like https://usehooks-ts.com/react-hook/use-timeout but with OO API.
 *
 * The API allows the caller to start, stop, restart, or change the
 * callback or delay at any time. The timeout is automatically
 * destroyed when the owner component unmounts, regardless of its
 * state at that time.
 */
function useTimeout() {
  return useJavascriptTimer(setTimeout, clearTimeout);
}
function useJavascriptTimer(setIntervalOrTimeout, clearIntervalOrTimeout) {
  const id = (0, _react.useRef)();
  const api = {
    start(fn, millis) {
      api.stop();
      id.current = setIntervalOrTimeout(fn, millis);
    },
    stop() {
      if (id.current !== undefined) clearIntervalOrTimeout(id.current);
      id.current = undefined;
    }
  };

  // Invoked just to set up a cleanup at unmount time:
  (0, _react.useEffect)(() => api.stop, []);
  return (0, _react.useRef)(api).current;
}
//# sourceMappingURL=use_hooks.js.map